# History

## 0.3.0

* minimum yt version is now 4.1
* new feature: pop-up tooltips [#44](https://github.com/yt-project/yt_idv/pull/44)
* new feature: isocontour shader [#40](https://github.com/yt-project/yt_idv/pull/40)
* enhancement: resizeable windows [#57](https://github.com/yt-project/yt_idv/pull/57)

## 0.2.3
* Fixes to manifest, restoring pypi functionality.

## 0.2.2
* bug fixes and improvements: full change history to come in upcoming minor release.

## 0.2.0

* Add grid positions annotation
* Add OSMesa rendering context for off-screen rendering
* Add geometry shader support
* Add tests and a handful of new examples
* Fix rendering meshes
* Regularize uniform names across shaders

## 0.1.0

* First release on PyPI.
